@@ -4,6 +4,7 @@
 The LaunchPad manages the FireWorks database.
 """
 import datetime
+import os
 import time
 from fireworks.core.fw_config import FWConfig
 from fireworks.utilities.fw_serializers import FWSerializable
@@ -92,6 +93,15 @@ class LaunchPad(FWSerializable):
         return LaunchPad(d['host'], d['port'], d['name'], d['username'], d['password'], logdir,
                          strm_lvl, user_indices, wf_user_indices)
 
+    @classmethod
+    def auto_load(cls):
+        if FWConfig().LAUNCHPAD_LOC:
+            return LaunchPad.from_file(FWConfig().LAUNCHPAD_LOC)
+        elif FWConfig().CONFIG_FILE_DIR:
+            return LaunchPad.from_file(os.path.join(FWConfig().CONFIG_FILE_DIR, 'my_launchpad.yaml'))
+        return LaunchPad()
+
+
     def reset(self, password, require_password=True):
         """
         Create a new FireWorks database. This will overwrite the existing FireWorks database! \
@@ -217,29 +227,41 @@ class LaunchPad(FWSerializable):
 
         return Workflow(fws, links_dict['links'], links_dict['name'], links_dict['metadata'])
 
-    def get_fw_ids(self, query=None, sort=None, limit=0):
+    def get_fw_ids(self, query=None, sort=None, limit=0, count_only=False):
         """
         Return all the fw ids that match a query,
-        :param query: a dict representing a Mongo query
+        :param query: (dict) representing a Mongo query
+        :param sort: [(str,str)] sort argument in Pymongo format
+        :param limit: (int) limit the results
+        :param count_only: (bool) only return the count rather than explicit ids
         """
         fw_ids = []
         criteria = query if query else {}
+
+        if count_only:
+            return self.fireworks.find(criteria, {"fw_id": True}, sort=sort).limit(limit).count()
+
         for fw in self.fireworks.find(criteria, {"fw_id": True}, sort=sort).limit(limit):
             fw_ids.append(fw["fw_id"])
-
         return fw_ids
 
-    def get_wf_ids(self, query=None, sort=None, limit=0):
+    def get_wf_ids(self, query=None, sort=None, limit=0, count_only=False):
         """
         Return one fw id for all workflows that match a query,
-        :param query: a dict representing a Mongo query
+        :param query: (dict) representing a Mongo query
+        :param sort: [(str,str)] sort argument in Pymongo format
+        :param limit: (int) limit the results
+        :param count_only: (bool) only return the count rather than explicit ids
         """
-        fw_ids = []
+        wf_ids = []
         criteria = query if query else {}
-        for fw in self.workflows.find(criteria, {"nodes": True}, sort=sort).limit(limit):
-            fw_ids.append(fw["nodes"][0])
+        if count_only:
+            return self.workflows.find(criteria, {"nodes": True}, sort=sort).limit(limit).count()
 
-        return fw_ids
+        for fw in self.workflows.find(criteria, {"nodes": True}, sort=sort).limit(limit):
+            wf_ids.append(fw["nodes"][0])
+
+        return wf_ids
 
     def run_exists(self, fworker=None):
         """
@@ -256,6 +278,8 @@ class LaunchPad(FWSerializable):
         self.fireworks.ensure_index('fw_id', unique=True)
         self.fireworks.ensure_index('state')
         self.fireworks.ensure_index('spec._category')
+        self.fireworks.ensure_index('created_on')
+        self.fireworks.ensure_index('name')
 
         self.launches.ensure_index('launch_id', unique=True)
         self.launches.ensure_index('state')
@@ -264,6 +288,10 @@ class LaunchPad(FWSerializable):
         self.launches.ensure_index('host')
         self.launches.ensure_index('ip')
 
+        self.workflows.ensure_index('name')
+        self.workflows.ensure_index('created_on')
+        self.workflows.ensure_index('updated_on')
+
         for idx in self.user_indices:
             self.fireworks.ensure_index(idx)
 
