@@ -122,11 +122,17 @@ def rapidfire(launchpad, fworker, qadapter, launch_dir='.', nlaunches=0, njobs_q
     try:
         l_logger.info('getting queue adapter')
 
-        block_dir = create_datestamp_dir(launch_dir, l_logger)
+        prev_blocks = sorted(glob.glob(os.path.join(launch_dir, 'block_*')), reverse=True)
+        if prev_blocks and not FWConfig().ALWAYS_CREATE_NEW_BLOCK:
+            block_dir = os.path.abspath(os.path.join(launch_dir, prev_blocks[0]))
+            l_logger.info('Found previous block, using {}'.format(block_dir))
+        else:
+            block_dir = create_datestamp_dir(launch_dir, l_logger)
 
         while True:
             # get number of jobs in queue
             jobs_in_queue = _get_number_of_jobs_in_queue(qadapter, njobs_queue, l_logger)
+            job_counter = 0  # this is for QSTAT_FREQUENCY option
 
             while jobs_in_queue < njobs_queue and launchpad.run_exists(fworker):
                 l_logger.info('Launching a rocket!')
@@ -146,9 +152,10 @@ def rapidfire(launchpad, fworker, qadapter, launch_dir='.', nlaunches=0, njobs_q
                 # wait for the queue system to update
                 l_logger.info('Sleeping for {} seconds...zzz...'.format(FWConfig().QUEUE_UPDATE_INTERVAL))
                 time.sleep(FWConfig().QUEUE_UPDATE_INTERVAL)
-                if FWConfig().AVOID_MANY_QSTATS:
-                    jobs_in_queue += 1
-                else:
+                jobs_in_queue += 1
+                job_counter += 1
+                if job_counter % FWConfig().QSTAT_FREQUENCY == 0:
+                    job_counter = 0
                     jobs_in_queue = _get_number_of_jobs_in_queue(qadapter, njobs_queue, l_logger)
 
             if num_launched == nlaunches or nlaunches == 0:
@@ -189,8 +196,7 @@ def _get_number_of_jobs_in_queue(qadapter, njobs_queue, l_logger):
                 l_logger.info('{} jobs in queue. Maximum allowed by user: {}'.format(jobs_in_queue, njobs_queue))
                 return jobs_in_queue
         except:
-            pass
-        l_logger.warn('Could not get number of jobs in queue! Sleeping {} secs...zzz...'.format(RETRY_INTERVAL))
+            log_exception(l_logger, 'Could not get number of jobs in queue! Sleeping {} secs...zzz...'.format(RETRY_INTERVAL))
         time.sleep(RETRY_INTERVAL)
         RETRY_INTERVAL *= 2
 
