@@ -65,15 +65,17 @@ def lpad():
     rerun_fw = subparsers.add_parser('rerun_fw', help='re-run a FireWork (reset its previous launches)')
     rerun_fw.add_argument('fw_id', help='FireWork id', type=int)
 
+    rerun_fizzled = subparsers.add_parser('rerun_fizzled', help='re-run FIZZLED FireWorks)')
+
     reservation_parser = subparsers.add_parser('detect_unreserved', help='Find launches with stale reservations')
     reservation_parser.add_argument('--time', help='expiration time (seconds)',
                                     default=FWConfig().RESERVATION_EXPIRATION_SECS, type=int)
-    reservation_parser.add_argument('--fix', help='cancel bad reservations', action='store_true')
+    reservation_parser.add_argument('--mark', help='cancel bad reservations', action='store_true')
 
     fizzled_parser = subparsers.add_parser('detect_fizzled', help='Find launches that have FIZZLED')
     fizzled_parser.add_argument('--time', help='expiration time (seconds)', default=FWConfig().RUN_EXPIRATION_SECS,
                                 type=int)
-    fizzled_parser.add_argument('--fix', help='mark fizzled', action='store_true')
+    fizzled_parser.add_argument('--mark', help='mark fizzled', action='store_true')
 
     defuse_parser = subparsers.add_parser('defuse', help='cancel (de-fuse) an entire Workflow')
     defuse_parser.add_argument('fw_id', help='Any FireWork id in the workflow to defuse', type=int)
@@ -173,12 +175,12 @@ def lpad():
             else:
                 sort = None
 
-            ids = lp.get_wf_ids(query, sort, args.max)
+            ids = lp.get_wf_ids(query, sort, args.max, count_only=args.display_format == 'count')
             wfs = []
             if args.display_format == 'ids':
                 wfs = ids
             elif args.display_format == 'count':
-                wfs = [len(ids)]
+                wfs = [ids]
             else:
                 for id in ids:
                     wf = lp.get_wf_by_fw_id(id)
@@ -226,12 +228,12 @@ def lpad():
             else:
                 sort = None
 
-            ids = lp.get_fw_ids(query, sort, args.max)
+            ids = lp.get_fw_ids(query, sort, args.max, count_only=args.display_format == 'count')
             fws = []
             if args.display_format == 'ids':
                 fws = ids
             elif args.display_format == 'count':
-                fws = [len(ids)]
+                fws = [ids]
             else:
                 for id in ids:
                     fw = lp.get_fw_by_id(id)
@@ -269,6 +271,12 @@ def lpad():
         elif args.command == 'rerun_fw':
             lp.rerun_fw(args.fw_id)
 
+        elif args.command == 'rerun_fizzled':
+            fw_ids = lp.get_fw_ids({"state": "FIZZLED"})
+            for fw_id in fw_ids:
+                lp.rerun_fw(fw_id)
+                print 'RERAN', fw_id
+
 
 if __name__ == '__main__':
     lpad()
\ No newline at end of file
